<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<defaultcodec>windows-1251</defaultcodec>
<context>
    <name>harmattan</name>
    <message>
        <location line="+1"/>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>QSoftKeyManager</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Выбрать</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
</context>
<context>
    <name>QColorDialog</name>
    <message>
        <source>Hu&amp;e:</source>
        <translation>&amp;Тон:</translation>
    </message>
    <message>
        <source>&amp;Sat:</source>
        <translation>&amp;Нас:</translation>
    </message>
    <message>
        <source>&amp;Val:</source>
        <translation>&amp;Ярк:</translation>
    </message>
    <message>
        <source>&amp;Red:</source>
        <translation>&amp;Красный:</translation>
    </message>
    <message>
        <source>&amp;Green:</source>
        <translation>&amp;Зелёный:</translation>
    </message>
    <message>
        <source>Bl&amp;ue:</source>
        <translation>С&amp;иний:</translation>
    </message>
    <message>
        <source>A&amp;lpha channel:</source>
        <translation>&amp;Альфа-канал:</translation>
    </message>
    <message>
        <source>Select Color</source>
        <translation>Выбор цвета</translation>
    </message>
    <message>
        <source>&amp;Basic colors</source>
        <translation>&amp;Основные цвета</translation>
    </message>
    <message>
        <source>&amp;Custom colors</source>
        <translation>&amp;Пользовательские цвета</translation>
    </message>
    <message>
        <source>&amp;Add to Custom Colors</source>
        <translation>&amp;Добавить к пользовательским цветам</translation>
    </message>
</context>
<context>
    <name>QDialogButtonBox</name>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;ОК</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Сохранить</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>От&amp;мена</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Да</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Нет</translation>
    </message>
</context>
<context>
    <name>QFontDatabase</name>
    <message>
        <source>Normal</source>
        <translation>Обычный</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Жирный</translation>
    </message>
    <message>
        <source>Demi Bold</source>
        <translation>Полужирный</translation>
    </message>
    <message>
        <source>Black</source>
        <translation>Чёрный</translation>
    </message>
    <message>
        <source>Demi</source>
        <translation>Средний</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Светлый</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Курсив</translation>
    </message>
    <message>
        <source>Oblique</source>
        <translation>Наклонный</translation>
    </message>
    <message>
        <source>Any</source>
        <translation>Любая</translation>
    </message>
    <message>
        <source>Latin</source>
        <translation>Латиница</translation>
    </message>
    <message>
        <source>Greek</source>
        <translation>Греческая</translation>
    </message>
    <message>
        <source>Cyrillic</source>
        <translation>Кириллица</translation>
    </message>
    <message>
        <source>Armenian</source>
        <translation>Армянская</translation>
    </message>
    <message>
        <source>Hebrew</source>
        <translation>Иврит</translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation>Арабская</translation>
    </message>
    <message>
        <source>Syriac</source>
        <translation>Сирийская</translation>
    </message>
    <message>
        <source>Thaana</source>
        <translation>Таана</translation>
    </message>
    <message>
        <source>Devanagari</source>
        <translation>Деванагири</translation>
    </message>
    <message>
        <source>Bengali</source>
        <translation>Бенгальская</translation>
    </message>
    <message>
        <source>Gurmukhi</source>
        <translation>Гурмукхи</translation>
    </message>
    <message>
        <source>Gujarati</source>
        <translation>Гуджарати</translation>
    </message>
    <message>
        <source>Oriya</source>
        <translation>Ория</translation>
    </message>
    <message>
        <source>Tamil</source>
        <translation>Тамильская</translation>
    </message>
    <message>
        <source>Telugu</source>
        <translation>Телугу</translation>
    </message>
    <message>
        <source>Kannada</source>
        <translation>Каннада</translation>
    </message>
    <message>
        <source>Malayalam</source>
        <translation>Малаяльская</translation>
    </message>
    <message>
        <source>Sinhala</source>
        <translation>Сингальская</translation>
    </message>
    <message>
        <source>Thai</source>
        <translation>Тайская</translation>
    </message>
    <message>
        <source>Lao</source>
        <translation>Лаосская</translation>
    </message>
    <message>
        <source>Tibetan</source>
        <translation>Тибетская</translation>
    </message>
    <message>
        <source>Myanmar</source>
        <translation>Майанмарская</translation>
    </message>
    <message>
        <source>Georgian</source>
        <translation>Грузинская</translation>
    </message>
    <message>
        <source>Khmer</source>
        <translation>Кхмерская</translation>
    </message>
    <message>
        <source>Simplified Chinese</source>
        <translation>Китайская упрощённая</translation>
    </message>
    <message>
        <source>Traditional Chinese</source>
        <translation>Китайская традиционная</translation>
    </message>
    <message>
        <source>Japanese</source>
        <translation>Японская</translation>
    </message>
    <message>
        <source>Korean</source>
        <translation>Корейская</translation>
    </message>
    <message>
        <source>Vietnamese</source>
        <translation>Вьетнамская</translation>
    </message>
    <message>
        <source>Symbol</source>
        <translation>Символьная</translation>
    </message>
    <message>
        <source>Ogham</source>
        <translation>Огамическая</translation>
    </message>
    <message>
        <source>Runic</source>
        <translation>Руническая</translation>
    </message>
    <message>
        <source>N&apos;Ko</source>
        <translation>Нко</translation>
    </message>
</context>
<context>
    <name>QFontDialog</name>
    <message>
        <source>&amp;Font</source>
        <translation>&amp;Шрифт</translation>
    </message>
    <message>
        <source>Font st&amp;yle</source>
        <translation>&amp;Начертание</translation>
    </message>
    <message>
        <source>&amp;Size</source>
        <translation>&amp;Размер</translation>
    </message>
    <message>
        <source>Effects</source>
        <translation>Эффекты</translation>
    </message>
    <message>
        <source>Stri&amp;keout</source>
        <translation>Зачёр&amp;кнутый</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>П&amp;одчёркнутый</translation>
    </message>
    <message>
        <source>Sample</source>
        <translation>Пример</translation>
    </message>
    <message>
        <source>Wr&amp;iting System</source>
        <translation>&amp;Система письма</translation>
    </message>
    <message>
        <source>Select Font</source>
        <translation>Выбор шрифта</translation>
    </message>
</context>
<context>
    <name>Details</name>
    <message>
        <location filename="../../ui/details.ui" line="+23"/>
        <source>Information for station</source>
        <translation>Информация по станции </translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/mainwindow.cpp" line="+380"/>
        <source>Installed maps:</source>
        <translation>Установленные карты:</translation>
    </message>
    <message>
        <location line="-1117"/>
        <source>Loading...</source>
        <translation>Загрузка...</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="+148"/>
        <location line="+420"/>
        <source>Find</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <location line="-357"/>
        <source>Waiting time</source>
        <translation>Время ожидания</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Time to station:</source>
        <translation>Время до станции:</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Description</source>
        <translation>Описание</translation>
    </message>
    <message>
        <location line="+130"/>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Язык</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>&amp;View</source>
        <translation>&amp;Вид</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Info</source>
        <translation>&amp;Инфо</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <location line="+90"/>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Alt+Del</source>
        <translation></translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Save As...</source>
        <translation>Сохранить как...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location line="+20"/>
        <location line="+3"/>
        <source>Zoom in</source>
        <translation>Увеличить</translation>
    </message>
    <message>
        <location line="+12"/>
        <location line="+3"/>
        <source>Zoom out</source>
        <translation>Уменьшить</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Save scale</source>
        <translation>Сохранять масштаб</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Preference</source>
        <translation>Дополнительно</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Show time</source>
        <translation>Показывать время</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Show hint</source>
        <translation>Показывать подсказки</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Zoom to fit</source>
        <translation>Вписать</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Save position</source>
        <translation>Сохранять позицию</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Add maps...</source>
        <translation>Добавить карты...</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Screen mode</source>
        <translation>Режим экрана</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Alt+Return</source>
        <translation></translation>
    </message>
    <message>
        <location line="-28"/>
        <source>Transliterate</source>
        <translation>Транслитерация</translation>
    </message>
    <message>
        <location line="-355"/>
        <source>Routes</source>
        <translation>Маршруты</translation>
    </message>
    <message>
        <location line="+335"/>
        <source>About...</source>
        <translation>О программе...</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="+524"/>
        <source>Open file</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Map</source>
        <translation>Карта</translation>
    </message>
    <message>
        <source>Save file</source>
        <translation>Сохранить файл</translation>
    </message>
    <message>
        <source>Unknown author</source>
        <translation>Неизвестный автор</translation>
    </message>
    <message>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <source>transit system map</source>
        <translation>карта транспортной системы</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <source>Data files by</source>
        <translation>Файлы данных предоставил</translation>
    </message>
    <message>
        <source>Author of map file format</source>
        <translation>Автор формата файла карт</translation>
    </message>
    <message>
        <source>About current map file</source>
        <translation>О текущем файле карты</translation>
    </message>
    <message>
        <source>Author of translation: Gusak Leonid</source>
        <translation>Автор перевода: Гусак Леонид</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <location line="+219"/>
        <source>All</source>
        <translation>Все</translation>
    </message>
    <message>
        <location line="-425"/>
        <location line="+425"/>
        <source>Information</source>
        <translation>Информация</translation>
    </message>
    <message>
        <location line="-422"/>
        <source>Start</source>
        <translation>Начальная</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Finish</source>
        <translation>Конечная</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Default start</source>
        <translation>Начальная по умолчанию</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>This is the first launch of the program.
Want to download more cities?</source>
        <translation>Это первый запуск программы.
Желаете загрузить больше городов?</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Yes</source>
        <translation>&amp;Да</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>&amp;No</source>
        <translation>&amp;Нет</translation>
    </message>
    <message>
        <location line="+381"/>
        <source>Categories</source>
        <translation>Категории</translation>
    </message>
    <message>
        <location line="+253"/>
        <source>Add maps</source>
        <translation>Добавление карты</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>1. Wait until loaded site...
2. Select map
3. Save file map here:</source>
        <translation>1. Дождаться загрузки сайта...
2. Выбрать карту
3. Сохранить файл карты:</translation>
    </message>
    <message>
        <source>Author of this map file</source>
        <translation>Автор этого файла карты</translation>
    </message>
    <message>
        <source>This program uses</source>
        <translation>Эта программа использует</translation>
    </message>
    <message>
        <source>This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.</source>
        <translation>Эта программа распространяется в надежде, что она будет полезной, но БЕЗ ВСЯКИХ ГАРАНТИЙ, в том числе подразумеваемых гарантий ТОВАРНОГО СОСТОЯНИЯ ПРИ ПРОДАЖЕ и ГОДНОСТИ ДЛЯ ОПРЕДЕЛЁННОГО ПРИМЕНЕНИЯ. Смотрите Стандартную Общественную Лицензию GNU для получения дополнительной информации.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../../ui/settings.ui" line="+26"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Interface</source>
        <translation>Интерфейс</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Custom font and style for station</source>
        <translation>Настраиваемый шрифт для станции</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Font and style for station name</source>
        <translation>Шрифт и стиль названий станций</translation>
    </message>
    <message>
        <location line="+66"/>
        <source>Font...</source>
        <translation>Шрифт...</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Back color</source>
        <translation>Фон</translation>
    </message>
    <message>
        <location line="+184"/>
        <source>Map back color</source>
        <translation>Цвет фона карты</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale of interface</source>
        <translation>Масштаб интерфейса</translation>
    </message>
    <message>
        <source>Caching graphics</source>
        <translation>Кешировать графику</translation>
    </message>
    <message>
        <location line="+167"/>
        <source>Simple graphics for transfers*</source>
        <translation>Упрощённая графика для переходов*</translation>
    </message>
    <message>
        <source>Background</source>
        <translation>Фон</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="+59"/>
        <source>Color...</source>
        <translation>Цвет...</translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="-320"/>
        <source>Shadow</source>
        <translation>Тень</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Upper case</source>
        <translation>Все заглавные</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Word wrap*</source>
        <translation>Перенос слов*</translation>
    </message>
    <message>
        <location line="+155"/>
        <source>Full screen mode*</source>
        <translation>Полноэкранный режим*</translation>
    </message>
    <message>
        <location line="-117"/>
        <source>Transparency when drawing the route</source>
        <translation>Прозрачность при прорисовке маршрута</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Show a scrollbar</source>
        <translation>Отображать полосы прокрутки</translation>
    </message>
    <message>
        <source>Full screen mode</source>
        <translation>Полноэкранный режим</translation>
    </message>
    <message>
        <location line="+53"/>
        <source>Performance</source>
        <translation>Производительность</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Cache graphics to raster</source>
        <translation>Кешировать графику в растр</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show time to the stations</source>
        <translation>Показывать время до станций</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show the background for map</source>
        <translation>Отображать фон карты</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Antialiasing filter</source>
        <translation>Сглаживать изображение</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Fast scrolling (without antialiasing)</source>
        <translation>Быстрый скроллинг (без сглаживания)</translation>
    </message>
    <message>
        <source>Simple graphics for transfers</source>
        <translation>Упрощённая графика для переходов</translation>
    </message>
    <message>
        <location line="+52"/>
        <source>Other</source>
        <translation>Дополнительно</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Cache</source>
        <translation>Кеш</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Clean the cache on exit</source>
        <translation>Очищать кеш при выходе</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Empty Now</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Restore default settings</source>
        <translation>Настройки по умолчанию</translation>
    </message>
</context>
<context>
    <name>TMapView</name>
    <message>
        <source>Information</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Начальная</translation>
    </message>
    <message>
        <source>Finish</source>
        <translation>Конечная</translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="+397"/>
        <source>Day</source>
        <translation>День</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Night</source>
        <translation>Ночь</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ignore</source>
        <translation>Не учитывать</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Rush Hour</source>
        <translation>Час-пик</translation>
    </message>
    <message>
        <location line="+106"/>
        <source>Cannot open file mapping:
%1</source>
        <translation>Невозможно открыть файл карты:
%1</translation>
    </message>
    <message>
        <location line="+1168"/>
        <source>line</source>
        <translation>линия</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Begin station:</source>
        <translation>Начальная станция:</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Go to station:</source>
        <translation>Ехать до станции:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Transfer to station:</source>
        <translation>Переход на станцию:</translation>
    </message>
    <message>
        <location line="+270"/>
        <source>Save file</source>
        <translation>Сохранить файл</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Все</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Категории</translation>
    </message>
    <message>
        <source>Transfer at station:</source>
        <translation>Переход на станцию:</translation>
    </message>
    <message>
        <location line="-265"/>
        <source>Final station:</source>
        <translation>Конечная станция:</translation>
    </message>
    <message>
        <location line="+7"/>
        <location line="+5"/>
        <source>st.</source>
        <translation>станц.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Travel time</source>
        <translation>Время в пути</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>min.</source>
        <translation>мин.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>transf.</source>
        <translation>перех.</translation>
    </message>
</context>
<context>
    <name>UnZip</name>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="+1138"/>
        <source>ZIP operation completed successfully.</source>
        <translation>Операции с ZIP файлом закончены успешно.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Failed to initialize or load zlib library.</source>
        <translation>Невозможно инициализировать или загрузить библиотеку zlib.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>zlib library error.</source>
        <translation>Ошибка библиотеки zlib.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Unable to create or open file.</source>
        <translation>Невозможно создать или открыть файл.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Partially corrupted archive. Some files might be extracted.</source>
        <translation>Частично повреждённый архив. Некоторые файлы могут быть извлечены.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Corrupted archive.</source>
        <translation>Повреждённый архив.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Wrong password.</source>
        <translation>Неверный пароль.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No archive has been created yet.</source>
        <translation>Архив не был создан.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>File or directory does not exist.</source>
        <translation>Отсутствует файл или директория.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>File read error.</source>
        <translation>Ошибка чтения файла.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>File write error.</source>
        <translation>Ошибка записи файла.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>File seek error.</source>
        <translation>Ошибка поиска в файле.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Unable to create a directory.</source>
        <translation>Невозможно создать директорию.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Invalid device.</source>
        <translation>Неверное устройство.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Invalid or incompatible zip archive.</source>
        <translation>Неверный или незаконченный zip архив.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Inconsistent headers. Archive might be corrupted.</source>
        <translation>Несовместимый заголовок или архив повреждён.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Unknown error.</source>
        <translation>Неизвестная ошибка.</translation>
    </message>
</context>
<context>
    <name>TMobileUi</name>
    <message>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
</context>
<context>
    <name>About</name>
    <message>
        <location filename="../../src/about.h" line="+28"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Unknown author</source>
        <translation>Неизвестный автор</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>transit system map</source>
        <translation>карта транспортной системы</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Author of map file format</source>
        <translation>Автор формата файла карт</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>About current map file</source>
        <translation>О текущем файле карты</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>This program uses</source>
        <translation>Эта программа использует</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.</source>
        <translation>Эта программа распространяется в надежде, что она будет полезной, но БЕЗ ВСЯКИХ ГАРАНТИЙ, в том числе подразумеваемых гарантий ТОВАРНОГО СОСТОЯНИЯ ПРИ ПРОДАЖЕ и ГОДНОСТИ ДЛЯ ОПРЕДЕЛЁННОГО ПРИМЕНЕНИЯ. Смотрите Стандартную Общественную Лицензию GNU для получения дополнительной информации.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Author of translation: Gusak Leonid</source>
        <translation>Автор перевода: Гусак Леонид</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
</context>
<context>
    <name>Zip</name>
    <message>
        <location filename="../../src/zip/zip.cpp" line="+1205"/>
        <source>ZIP operation completed successfully.</source>
        <translation>Операции с ZIP файлом закончены успешно.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Failed to initialize or load zlib library.</source>
        <translation>Невозможно инициализировать или загрузить библиотеку zlib.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>zlib library error.</source>
        <translation>Ошибка библиотеки zlib.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Unable to create or open file.</source>
        <translation>Невозможно создать или открыть файл.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No archive has been created yet.</source>
        <translation>Архив не был создан.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>File or directory does not exist.</source>
        <translation>Отсутствует файл или директория.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>File read error.</source>
        <translation>Ошибка чтения файла.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>File write error.</source>
        <translation>Ошибка записи файла.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>File seek error.</source>
        <translation>Ошибка поиска в файле.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Unknown error.</source>
        <translation>Неизвестная ошибка.</translation>
    </message>
</context>
</TS>
